Module endpoints

Module endpoints 

Implementations of the Endpoint trait for individual Cloudflare API endpoints, e.g. DNS or Workers. If you want to add a new Cloudflare API to this crate, simply add a new submodule of this endpoints module.

Modules

account
argo_tunnel
dns
load_balancing
plan
r2
user
workers
workerskv
zone